@@ -337,7 +337,22 @@ class Runner:
                 target_username = self.target_hardware_secret.get("username", "")
                 target_password = self.target_hardware_secret.get("password", "")
                 target_machine_name = self.target_hardware.get("slug", "")
-                target_auth_token = self.primitive.host_config.get("token", "")
+                target_auth_token = None
+
+                create_token_result = self.primitive.auth.create_token(
+                    key_name=f"pxe-boot-{self.target_hardware['slug']}-{int(time.time())}"
+                )
+                if create_token_result and create_token_result.data:
+                    try:
+                        target_auth_token = create_token_result.data[
+                            "authenticationTokenCreate"
+                        ]["key"]
+                    except (KeyError, TypeError):
+                        target_auth_token = None
+
+                if not target_auth_token:
+                    logger.error("Failed to create authentication token for PXE boot")
+                    return True
 
                 await sync_to_async(
                     self.primitive.operating_systems._prepare_operating_system_for_pxe
