@@ -5,6 +5,7 @@ from primitive.utils.actions import BaseAction
 from ..utils.auth import guard
 from ..utils.config import read_config_file, update_config_file
 from .graphql.queries import whoami_query
+from .graphql.mutations import authentication_token_create
 
 
 class Auth(BaseAction):
@@ -33,3 +34,14 @@ class Auth(BaseAction):
         else:
             full_config[host] = new_host_config
         update_config_file(new_config=full_config)
+
+    @guard
+    def create_token(self, key_name: str):
+        mutation = gql(authentication_token_create)
+        variables = {"input": {"keyName": key_name}}
+
+        result = self.primitive.session.execute(
+            mutation, variable_values=variables, get_execution_result=True
+        )
+
+        return result
