@@ -14,7 +14,7 @@ HOME_DIRECTORY = Path.home()
 
 
 class Daemons:
-    def __init__(self, primitive) -> None:
+    def __init__(self, primitive, root_user: bool = False) -> None:
         self.primitive: Primitive = primitive
         command_flags = ""
 
@@ -41,10 +41,12 @@ class Daemons:
                     "agent": LaunchService(
                         label="tech.primitive.agent",
                         command=f"{command_flags} agent",
+                        root_user=root_user,
                     ),
                     "monitor": LaunchService(
                         label="tech.primitive.monitor",
                         command=f"{command_flags} monitor",
+                        root_user=root_user,
                     ),
                 }
             case _:
