@@ -191,14 +191,18 @@ class OperatingSystems(BaseAction):
                 directory=directory,
             )
 
-        except Exception as exception:
-            logger.error(
-                "An error occurred during remote download, cleaning up partial files"
-            )
+        except (Exception, KeyboardInterrupt) as exception:
+            if isinstance(exception, KeyboardInterrupt):
+                logger.info("Cleaning up partial files")
+            else:
+                logger.error(
+                    "An error occurred during remote download, cleaning up partial files"
+                )
+
             self._remove_partial_files(
                 operating_system=remote_operating_system_name, directory=directory
             )
-            raise exception
+            raise
 
         logger.info("Validating iso checksum")
         checksum_valid = self.primitive.operating_systems._validate_checksum(
@@ -620,12 +624,17 @@ class OperatingSystems(BaseAction):
                 output_path=checksum_directory,
                 **download_file_args,
             )
-        except Exception as exception:
-            logger.error("An error occurred during download, cleaning up partial files")
+        except (Exception, KeyboardInterrupt) as exception:
+            if isinstance(exception, KeyboardInterrupt):
+                logger.info("Cleaning up partial files")
+            else:
+                logger.error(
+                    "An error occurred during remote download, cleaning up partial files"
+                )
             self._remove_partial_files(
                 operating_system=operating_system["slug"], directory=directory
             )
-            raise exception
+            raise
 
         logger.info("Validating iso checksum")
         checksum_file_type = (
@@ -966,7 +975,7 @@ curl -LsSf https://astral.sh/uv/install.sh | sh
 . /$USER/.local/bin/env
 . /$USER/.bashrc
 uv python install --default 3.14.0
-uv venv --no-project
+uv venv --no-project /$USER/.venv/
 . /$USER/.venv/bin/activate
 uv pip install --no-cache primitive
 primitive --host {self.primitive.host} config --auth-token {target_auth_token}
