@@ -3,7 +3,6 @@ import click
 import typing
 
 from loguru import logger
-from primitive.utils.click import abort_guard
 from primitive.utils.cache import get_operating_systems_cache
 from .exceptions import P_CLI_200, P_CLI_201
 
@@ -126,34 +125,6 @@ def create_command(
     logger.success("Operating system created in primitive.")
 
 
-def download_on_abort(context):
-    primitive: Primitive = context.obj.get("PRIMITIVE")
-
-    id = context.params["id"]
-    slug = context.params["slug"]
-    organization_slug = context.params["organization_slug"]
-    directory = context.params["directory"]
-
-    organization = (
-        primitive.organizations.get_organization(slug=organization_slug)
-        if organization_slug
-        else primitive.organizations.get_default_organization()
-    )
-
-    operating_system, _ = (
-        primitive.operating_systems._get_organization_or_global_operating_system(
-            id=id,
-            slug=slug,
-            organization_id=organization["id"],
-        )
-    )
-
-    logger.info("Removing partial files")
-    primitive.operating_systems._remove_partial_files(
-        operating_system=operating_system["slug"], directory=directory
-    )
-
-
 @cli.command("delete")
 @click.argument("operating-system-identifier")
 @click.option("--organization-slug", help="Organization slug", required=False)
@@ -249,7 +220,6 @@ def delete(
     is_flag=True,
     required=False,
 )
-@abort_guard(download_on_abort)
 @click.pass_context
 def download(
     context,
@@ -342,18 +312,6 @@ def remotes(context):
     pass
 
 
-def operating_system_remotes_download_on_abort(context):
-    primitive: Primitive = context.obj.get("PRIMITIVE")
-
-    directory = context.params["directory"]
-    operating_system = context.params["operating_system"]
-
-    logger.info("Removing partial files")
-    primitive.operating_systems._remove_partial_files(
-        operating_system=operating_system, directory=directory
-    )
-
-
 @remotes.command("download")
 @click.pass_context
 @click.argument("operating-system")
@@ -362,7 +320,6 @@ def operating_system_remotes_download_on_abort(context):
     help="Directory to download the operating system files to",
     required=False,
 )
-@abort_guard(operating_system_remotes_download_on_abort)
 def operating_system_remotes_download_command(
     context, operating_system, directory=None
 ):
@@ -413,7 +370,6 @@ def operating_system_remotes_download_command(
     is_flag=True,
     required=False,
 )
-@abort_guard(operating_system_remotes_download_on_abort)
 def operating_system_mirror_command(
     context,
     operating_system,
