@@ -4,7 +4,7 @@ import click
 from loguru import logger
 
 
-def print_result(message: str, context: click.Context, fg: str = None):
+def print_result(message: str | dict, context: click.Context, fg: str = None):
     """Print message to stdout or stderr"""
     if context.obj["DEBUG"]:
         logger.info(json.dumps(message))
